Paul Menzel has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/42199 )
Change subject: soc/intel/cannonlake: Make `acpi_create_gnvs()` static
......................................................................
soc/intel/cannonlake: Make `acpi_create_gnvs()` static
The function `acpi_create_gnvs()` is only used in this translation unit,
so make it `static`. This unifies it with the Skylake version
`src/soc/intel/skylake/acpi.c`.
Change-Id: I8f817aa46c75332ec5a5fa77e8772ae0f0e3a366
Signed-off-by: Paul Menzel <pmenzel(a)molgen.mpg.de>
---
M src/soc/intel/cannonlake/acpi.c
1 file changed, 1 insertion(+), 1 deletion(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/99/42199/1
diff --git a/src/soc/intel/cannonlake/acpi.c b/src/soc/intel/cannonlake/acpi.c
index 12758e1..886cba2 100644
--- a/src/soc/intel/cannonlake/acpi.c
+++ b/src/soc/intel/cannonlake/acpi.c
@@ -182,7 +182,7 @@
return read32((void *)pmc_bar + IRQ_REG);
}
-void acpi_create_gnvs(struct global_nvs_t *gnvs)
+static void acpi_create_gnvs(struct global_nvs_t *gnvs)
{
const struct soc_intel_cannonlake_config *config;
config = config_of_soc();
--
To view, visit https://review.coreboot.org/c/coreboot/+/45502
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I86ab643bc87253554346dfed3630eb9ddbd44eb3
Gerrit-Change-Number: 45502
Gerrit-PatchSet: 1
Gerrit-Owner: Angel Pons <th3fanbus(a)gmail.com>
Gerrit-Reviewer: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-MessageType: newchange
Patrick Rudolph has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/47709 )
Change subject: src/cpu: Remove unused symbols
......................................................................
src/cpu: Remove unused symbols
Remove the unused Kconfig symbol CPU_MICROCODE_MULTIPLE_FILES.
Change-Id: I18115e07694658a2f77c447d3ab5c899c1bdcc61
Signed-off-by: Patrick Rudolph <patrick.rudolph(a)9elements.com>
---
M src/cpu/Kconfig
M src/cpu/Makefile.inc
2 files changed, 0 insertions(+), 10 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/09/47709/1
diff --git a/src/cpu/Kconfig b/src/cpu/Kconfig
index 933e50f..297b1a1 100644
--- a/src/cpu/Kconfig
+++ b/src/cpu/Kconfig
@@ -111,7 +111,6 @@
config CPU_MICROCODE_CBFS_EXTERNAL_BINS
bool "Include external microcode binary"
select USE_CPU_MICROCODE_CBFS_BINS
- depends on !CPU_MICROCODE_MULTIPLE_FILES
help
Select this option if you want to include external binary files
in the CPUs native format. They will be included as a separate
@@ -128,7 +127,6 @@
config CPU_MICROCODE_CBFS_EXTERNAL_HEADER
bool "Include external microcode header files"
- depends on !CPU_MICROCODE_MULTIPLE_FILES
help
Select this option if you want to include external c header files
containing the CPU microcode. This will be included as a separate
@@ -179,12 +177,6 @@
endchoice
-config CPU_MICROCODE_MULTIPLE_FILES
- bool
- help
- Select this option to install separate microcode container files into
- CBFS instead of using the traditional monolithic microcode file format.
-
config CPU_MICROCODE_HEADER_FILES
string "List of space separated microcode header files with the path"
depends on CPU_MICROCODE_CBFS_EXTERNAL_HEADER
diff --git a/src/cpu/Makefile.inc b/src/cpu/Makefile.inc
index a072a8b..ec2f19f 100644
--- a/src/cpu/Makefile.inc
+++ b/src/cpu/Makefile.inc
@@ -13,9 +13,7 @@
## Rules for building the microcode blob in CBFS
################################################################################
-ifneq ($(CONFIG_CPU_MICROCODE_MULTIPLE_FILES), y)
cbfs-files-$(CONFIG_USE_CPU_MICROCODE_CBFS_BINS) += cpu_microcode_blob.bin
-endif
ifeq ($(CONFIG_CPU_MICROCODE_CBFS_EXTERNAL_HEADER),y)
cbfs-files-y += cpu_microcode_blob.bin
--
To view, visit https://review.coreboot.org/c/coreboot/+/42199
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I8f817aa46c75332ec5a5fa77e8772ae0f0e3a366
Gerrit-Change-Number: 42199
Gerrit-PatchSet: 1
Gerrit-Owner: Paul Menzel <paulepanter(a)users.sourceforge.net>
Gerrit-Reviewer: Patrick Rudolph <siro(a)das-labor.org>
Gerrit-MessageType: newchange
Angel Pons has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/45502 )
Change subject: nb/intel/sandybridge: Clean up `dram_freq` function
......................................................................
nb/intel/sandybridge: Clean up `dram_freq` function
The thing that this function initializes is the MPLL (Memory PLL). So,
call it by its name. Also add a missing newline in a printk, and update
a comment on the callsite of this function.
Tested on Asus P8Z77-V LX2, still boots.
Change-Id: I86ab643bc87253554346dfed3630eb9ddbd44eb3
Signed-off-by: Angel Pons <th3fanbus(a)gmail.com>
---
M src/northbridge/intel/sandybridge/raminit_native.c
1 file changed, 11 insertions(+), 11 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/02/45502/1
diff --git a/src/northbridge/intel/sandybridge/raminit_native.c b/src/northbridge/intel/sandybridge/raminit_native.c
index 64a381d..6b74405 100644
--- a/src/northbridge/intel/sandybridge/raminit_native.c
+++ b/src/northbridge/intel/sandybridge/raminit_native.c
@@ -459,7 +459,7 @@
if (ctrl->tCK > TCK_400MHZ) {
printk(BIOS_ERR,
"DRAM frequency is under lowest supported frequency (400 MHz). "
- "Increasing to 400 MHz as last resort");
+ "Increasing to 400 MHz as last resort.\n");
ctrl->tCK = TCK_400MHZ;
}
@@ -467,11 +467,11 @@
u8 val2;
u32 reg1 = 0;
/* Step 1 - Set target PCU frequency */
find_cas_tck(ctrl);
/*
* The PLL will never lock if the required frequency is already set.
* Exit early to prevent a system hang.
*/
reg1 = MCHBAR32(MC_BIOS_DATA);
@@ -479,16 +479,16 @@
if (val2)
return;
/* Step 2 - Select frequency in the MCU */
reg1 = ctrl->FRQ;
if (ctrl->base_freq == 100)
- reg1 |= 0x100; /* Enable 100Mhz REF clock */
+ reg1 |= 0x100; /* Use 100MHz reference clock */
- reg1 |= 0x80000000; /* set running bit */
+ reg1 |= (1 << 31); /* Set running bit */
MCHBAR32(MC_BIOS_REQ) = reg1;
int i = 0;
- printk(BIOS_DEBUG, "PLL busy... ");
- while (reg1 & 0x80000000) {
+ printk(BIOS_DEBUG, "MPLL busy... ");
+ while (reg1 & (1 << 31)) {
udelay(10);
i++;
reg1 = MCHBAR32(MC_BIOS_REQ);
@@ -499,11 +499,11 @@
reg1 = MCHBAR32(MC_BIOS_DATA);
val2 = (u8) reg1;
if (val2 >= ctrl->FRQ) {
- printk(BIOS_DEBUG, "MCU frequency is set at : %d MHz\n",
+ printk(BIOS_DEBUG, "MPLL frequency is set at : %d MHz\n",
(1000 << 8) / ctrl->tCK);
return;
}
- printk(BIOS_DEBUG, "PLL didn't lock. Retrying at lower frequency\n");
+ printk(BIOS_DEBUG, "MPLL didn't lock. Retrying at lower frequency\n");
ctrl->tCK++;
}
}
@@ -571,7 +571,7 @@
dram_dimm_mapping(ctrl);
}
- /* Set MC frequency */
+ /* Set MPLL frequency */
dram_freq(ctrl);
if (!fast_boot) {
@@ -467,11 +467,11 @@
u8 val2;
u32 reg1 = 0;
- /* Step 1 - Set target PCU frequency */
+ /* Step 1 - Determine target MPLL frequency */
find_cas_tck(ctrl);
/*
@@ -467,11 +467,11 @@
find_cas_tck(ctrl);
/*
- * The PLL will never lock if the required frequency is already set.
+ * The MPLL will never lock if the requested frequency is already set.
* Exit early to prevent a system hang.
*/
@@ -479,16 +479,16 @@
if (val2)
return;
- /* Step 2 - Select frequency in the MCU */
+ /* Step 2 - Request MPLL frequency */
reg1 = ctrl->FRQ;
if (ctrl->base_freq == 100)
--
To view, visit https://review.coreboot.org/c/coreboot/+/47709
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings
Gerrit-Project: coreboot
Gerrit-Branch: master
Gerrit-Change-Id: I18115e07694658a2f77c447d3ab5c899c1bdcc61
Gerrit-Change-Number: 47709
Gerrit-PatchSet: 1
Gerrit-Owner: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Reviewer: Martin Roth <martinroth(a)google.com>
Gerrit-Reviewer: Patrick Georgi <pgeorgi(a)google.com>
Gerrit-MessageType: newchange